@@ -11,12 +11,6 @@
 #include <QPropertyAnimation>
 #include <QPushButton>
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    typedef QEnterEvent QT_ENTER_EVENT;
-#else
-    typedef QEvent QT_ENTER_EVENT;
-#endif // QT_VERSION_CHECK(6, 0, 0)
-
 QT_BEGIN_NAMESPACE
 class QGraphicsOpacityEffect;
 class QGraphicsView;
@@ -51,7 +45,7 @@ public:
 
 protected slots:
     void showEvent(QShowEvent *event) override;
-    void enterEvent(QT_ENTER_EVENT *event) override;
+    void enterEvent(QEnterEvent *event) override;
     void leaveEvent(QEvent *event) override;
     void mousePressEvent(QMouseEvent *event) override;
     void mouseMoveEvent(QMouseEvent *event) override;
@@ -112,8 +106,11 @@ private slots:
     void on_actionLocateInFileManager_triggered();
     void on_actionQuitApp_triggered();
 
+    void doCloseWindow();
+
 private:
     bool updateFileWatcher(const QString & basePath = QString());
+    void updateGalleryButtonsVisibility();
 
 private:
     ActionManager *m_am;
